@@ -13,7 +13,7 @@ from typing import Any, Dict, List, Optional, Union
 import numba
 import numpy as np
 import quadpy
-from pymatgen import Spin
+from pymatgen.electronic_structure.core import Spin
 from pymatgen.util.coord import pbc_diff
 from scipy.interpolate import griddata
 
@@ -66,7 +66,7 @@ basic_scatterers = [i.name for i in AbstractBasicScattering.__subclasses__()]
 ni = {
     "high": {
         "triangle": quadpy.t2.schemes["xiao_gimbutas_50"](),
-        "quad": quadpy.c2.schemes["sommariva_50"](),
+        "quad": quadpy.c2.schemes["sommariva_55"](),
     },
     "medium": {
         "triangle": quadpy.t2.schemes["xiao_gimbutas_06"](),
@@ -79,13 +79,22 @@ ni = {
 }
 
 # ni = {
-#     "high": {"triangle": quadpy.t2.centroid(), "quad": quadpy.c2.dunavant_00()},
-#     "medium": {"triangle": quadpy.t2.centroid(), "quad": quadpy.c2.dunavant_00()},
-#     "low": {"triangle": quadpy.t2.centroid(), "quad": quadpy.c2.dunavant_00()},
+#     "high": {
+#         "triangle": quadpy.t2.schemes["centroid"](),
+#         "quad": quadpy.c2.schemes["dunavant_00"]()
+#     },
+#     "medium": {
+#         "triangle": quadpy.t2.schemes["centroid"](),
+#         "quad": quadpy.c2.schemes["dunavant_00"]()
+#     },
+#     "low": {
+#         "triangle": quadpy.t2.schemes["centroid"](),
+#         "quad": quadpy.c2.schemes["dunavant_00"]()
+#     },
 # }
 
 
-class ScatteringCalculator(object):
+class ScatteringCalculator:
     def __init__(
         self,
         settings: Dict[str, float],
@@ -333,7 +342,7 @@ class ScatteringCalculator(object):
                     )
 
         str_scats = ", ".join(scattering_type)
-        logger.info("Scattering mechanisms to be calculated: {}".format(str_scats))
+        logger.info(f"Scattering mechanisms to be calculated: {str_scats}")
 
         return [
             _scattering_mechanisms[name].from_amset_data(settings, amset_data)
@@ -353,7 +362,7 @@ class ScatteringCalculator(object):
         masks = {s: np.full(rate_shape[s], True) for s in spins}
 
         logger.info("Scattering information:")
-        log_list(["# ir k-points: {}".format(len(self.amset_data.ir_kpoints_idx))])
+        log_list([f"# ir k-points: {len(self.amset_data.ir_kpoints_idx)}"])
 
         for spin in spins:
             for b_idx in range(len(self.amset_data.energies[spin])):
@@ -367,11 +376,11 @@ class ScatteringCalculator(object):
                 ) = self.calculate_band_rates(spin, b_idx)
 
                 info = [
-                    "max rate: {:.4g}".format(rates[spin][..., b_idx, :].max()),
-                    "min rate: {:.4g}".format(rates[spin][..., b_idx, :].min()),
+                    f"max rate: {rates[spin][..., b_idx, :].max():.4g}",
+                    f"min rate: {rates[spin][..., b_idx, :].min():.4g}",
                 ]
                 log_list(info, level=logging.DEBUG)
-                log_list(["time: {:.4f} s".format(time.perf_counter() - t0)])
+                log_list([f"time: {time.perf_counter() - t0:.4f} s"])
 
             # fill in k-points outside Fermi-Dirac cutoffs with a default value
             rates[spin][masks[spin]] = 1e14
@@ -405,7 +414,7 @@ class ScatteringCalculator(object):
         fill_mask = mask[self.amset_data.ir_to_full_kpoint_mapping]
 
         n = np.sum(~fill_mask)
-        logger.info("  ├── # k-points within Fermi–Dirac cut-offs: {}".format(n))
+        logger.info(f"  ├── # k-points within Fermi–Dirac cut-offs: {n}")
 
         k_idx_in_cutoff = kpoints_idx[~mask]
         ir_idx_in_cutoff = np.arange(nkpoints)[~mask]
@@ -543,7 +552,7 @@ def scattering_worker(
                 *overlap_calculator_reference
             )
         else:
-            raise ValueError("Unrecognised overlap type: {}".format(overlap_type))
+            raise ValueError(f"Unrecognised overlap type: {overlap_type}")
 
         elastic_scatterers = [
             AcousticDeformationPotentialScattering.from_reference(*s)
@@ -806,6 +815,10 @@ def _interpolate_zero_rates(
     t0 = time.perf_counter()
     k_idx = np.arange(len(kpoints))
     for spin in rates:
+        # if a rate at a k-point for any spin, doping, or temperature is zero then
+        # flag it for interpolation
+        all_non_zero_rates = (rates[spin] > 1e7).all(axis=(0, 1, 2))
+
         for s, d, t, b in np.ndindex(rates[spin].shape[:-1]):
 
             if masks is not None:
@@ -813,8 +826,7 @@ def _interpolate_zero_rates(
             else:
                 mask = [True] * len(rates[spin][s, d, t, b])
 
-            non_zero_rates = rates[spin][s, d, t, b, mask] > 1e7
-            # non_zero_rates = rates[spin][s, d, t, b, mask] != 0
+            non_zero_rates = all_non_zero_rates[b][mask]
             zero_rate_idx = k_idx[mask][~non_zero_rates]
             non_zero_rate_idx = k_idx[mask][non_zero_rates]
 
@@ -836,7 +848,7 @@ def _interpolate_zero_rates(
                         method="nearest",
                     )
                 )
-                # rates[spin][s, d, t, b, zero_rate_idx] = 1e15
+                # rates[spin][s, d, t, b, zero_rate_idx] = 10 ** (15 + s)
 
             if pbar is not None:
                 pbar.update()
