@@ -1,6 +1,6 @@
 import h5py
 import numpy as np
-from pymatgen import Structure
+from pymatgen.core.structure import Structure
 
 from amset.constants import str_to_spin
 
@@ -12,7 +12,7 @@ __email__ = "aganose@lbl.gov"
 def write_coefficients(coeffs, gpoints, kpoints, structure, filename="coeffs.h5"):
     with h5py.File(filename, "w") as f:
         for spin, spin_coeffs in coeffs.items():
-            name = "coefficients_{}".format(spin.name)
+            name = f"coefficients_{spin.name}"
             dset = f.create_dataset(
                 name, spin_coeffs.shape, compression="gzip", dtype=np.complex
             )
